
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.31.3',
    'branch_nick': 'release-1.31',
    'revision_id': 'f2e040c456493ddac81cde66eb85c1174ab524a8',
    'revno': 12485
}
